local modName = select(1, ...)
local modVersion = GetAddOnMetadata(modName, "Version")
local modTitle = GetAddOnMetadata(modName, "Title")
local modDescription = GetAddOnMetadata(modName, "Notes")

local addon = LibStub("AceAddon-3.0"):GetAddon(modName)
local L	= LibStub("AceLocale-3.0"):GetLocale(modName)
local AceConfigReg = LibStub("AceConfigRegistry-3.0")

------------------------------------
-- create the show variable table --
------------------------------------
local SHOWN_VALUE = {
	QUANTITY = L["Quantity"],
	HANDINS = L["Hand-ins"],
	REMAINING = L["Remaining"]
}

--------------------------------------
-- create the floating menu options --
--------------------------------------
addon.menuOptions = {
	{
		text = L["Visible Item Options"],
		isTitle = true,
		notCheckable = 1,
	},
	{
		text = L["Show bank items"],
		checked = function() return addon.db.profile.ShowBankItems; end,
		keepShownOnClick = true,
		func = function()
					addon.db.profile.ShowBankItems = not addon.db.profile.ShowBankItems;
					addon.UpdateFrame();
					AceConfigReg:NotifyChange(modName);
				end,
	},
	{
		text = L["Show guild bank items"],
		checked = function() return addon.db.profile.ShowGuildBankItems; end,
		keepShownOnClick = true,
		func = function()
					addon.db.profile.ShowGuildBankItems = not addon.db.profile.ShowGuildBankItems;
					addon.UpdateFrame();
					AceConfigReg:NotifyChange(modName);
				end,
	},
	{
		text = L["Show minor items"],
		checked = function() return addon.db.profile.ShowMinorItems; end,
		keepShownOnClick = true,
		func = function()
					addon.db.profile.ShowMinorItems = not addon.db.profile.ShowMinorItems;
					addon:UpdateFrame();
					AceConfigReg:NotifyChange(modName);
				end,
	},
	{
		text = L["Show tooltips"],
		checked = function() return addon.db.profile.ShowTooltips; end,
		keepShownOnClick = true,
		func = function()
					addon.db.profile.ShowTooltips = not addon.db.profile.ShowTooltips;
					AceConfigReg:NotifyChange(modName);
				end,
	},
	{
		text = L["Show only when there are items"],
		checked = function() return addon.db.profile.ShowOnlyWhenThereAreItems; end,
		keepShownOnClick = true,
		func = function()
					addon.db.profile.ShowOnlyWhenThereAreItems = not addon.db.profile.ShowOnlyWhenThereAreItems;
					addon:UpdateFrame();
					AceConfigReg:NotifyChange(modName);
				end,
	},
	{
		text = L["Show Minimap Button"],
		checked = function() return addon.db.profile.ShowMinimapButton; end,
		keepShownOnClick = true,
		func = function()
					addon.db.profile.ShowMinimapButton = not addon.db.profile.ShowMinimapButton;
					addon:ToggleButton();
					AceConfigReg:NotifyChange(modName);
				end,
	},
	{
		text = L["Show count from other characters"],
		checked = function() return addon.db.profile.ShowItemsFromOtherCharacters; end,
		keepShownOnClick = true,
		func = function()
					addon.db.profile.ShowItemsFromOtherCharacters = not addon.db.profile.ShowItemsFromOtherCharacters;
					AceConfigReg:NotifyChange(modName);
				end,
	},
	{
		text = L["Value to show"], hasArrow = true,
		menuList = {
				{ 
					text = SHOWN_VALUE.QUANTITY,
					checked = function() return addon.db.profile.ShownValue == "QUANTITY"; end,
					func = function() addon.db.profile.ShownValue = "QUANTITY"; addon:UpdateFrame(); end,
				},
				{
					text = SHOWN_VALUE.HANDINS,
					checked = function() return addon.db.profile.ShownValue == "HANDINS"; end,
					func = function() addon.db.profile.ShownValue = "HANDINS"; addon:UpdateFrame(); end,
				},
				{ 
					text = SHOWN_VALUE.REMAINING, 
					checked = function() return addon.db.profile.ShownValue == "REMAINING"; end,
					func = function() addon.db.profile.ShownValue = "REMAINING"; addon:UpdateFrame(); end,
				},
		},
	},
	{
		text = "",
		disabled = true,
	},
	{
		text = L["Config"],
		checked = false,
		func = function()
					addon:OpenInterfacePage();
				end,
	},
	{
		text = CLOSE,
		checked = false,
	},
}

---------------------------------------
-- create the interface menu options --
---------------------------------------
addon.interfaceOptions = {
	name = L["Rep Items"],
	desc = L["Rep Item viewer"],
	type = "group",
	args = {
		version1 = {
			type = "description",
			name =	string.format(L["Version %s"], modVersion),
			--width = "full",
			order = 1,
		},		
		showButton = {
			type = "execute",
			name = "Show",
			width = "half",
			order = 2,
			hidden = function() return not addon.db.profile.frameClosedByUser; end,
			func = function() 
						addon.db.profile.frameClosedByUser = false;
						addon:ShowFrame(true);
						addon:UpdateFrame();
					end,
		},
		hideButton = {
			type = "execute",
			name = "Hide",
			width = "half",
			order = 3,
			hidden = function() return addon.db.profile.frameClosedByUser; end,
			func = function()
						addon.db.profile.frameClosedByUser = true;
						addon:ShowFrame(false);
					end,
		},
		header1 = {
			type = "header",
			name = L["Visible Item Options"],
			order = 4,
		},
		bankItems = {
			type = "toggle",
			name = L["Show bank items"],
			--width = "full",
			order = 5,
			get = function() return addon.db.profile.ShowBankItems; end,
			set = function() 
						addon.db.profile.ShowBankItems = not addon.db.profile.ShowBankItems;
						addon:UpdateFrame();
					end,
		},
		guildBankItems = {
			type = "toggle",
			name = L["Show guild bank items"],
			--width = "full",
			order = 5,
			get = function() return addon.db.profile.ShowGuildBankItems; end,
			set = function() 
						addon.db.profile.ShowGuildBankItems = not addon.db.profile.ShowGuildBankItems;
						addon:UpdateFrame();
					end,
		},
		minorItems = {
			type = "toggle",
			name = L["Show minor items"],
			--width = "full",
			order = 7,
			get = function() return addon.db.profile.ShowMinorItems; end,
			set = function() 
						addon.db.profile.ShowMinorItems = not addon.db.profile.ShowMinorItems;
						addon:UpdateFrame();
					end,
		},
		ShowTooltips = {
			type = "toggle",
			name = L["Show tooltips"],
			--width = "full",
			order = 8,
			get = function() return addon.db.profile.ShowTooltips; end,
			set = function()
						addon.db.profile.ShowTooltips = not addon.db.profile.ShowTooltips;
					end,
		},
		ShowMinimapButton = {
			type = "toggle",
			name = L["Show Minimap Button"],
			--width = "full",
			order = 9,
			get = function() return addon.db.profile.ShowMinimapButton; end,
			set = function()
						addon.db.profile.ShowMinimapButton = not addon.db.profile.ShowMinimapButton;
						addon:ToggleButton();
					end,
		},
		ShowOnlyWhenThereAreItems = {
			type = "toggle",
			name = L["Show only when there are items"],
			width = "full",
			order = 10,
			get = function() return addon.db.profile.ShowOnlyWhenThereAreItems; end,
			set = function() 
						addon.db.profile.ShowOnlyWhenThereAreItems = not addon.db.profile.ShowOnlyWhenThereAreItems;
						addon:UpdateFrame();
					end,
		},
		ShowOtherCharacterCount = {
			type = "toggle",
			name = L["Show count from other characters"],
			width = "full",
			order = 11,
			get = function() return addon.db.profile.ShowItemsFromOtherCharacters; end,
			set = function() 
						addon.db.profile.ShowItemsFromOtherCharacters = not addon.db.profile.ShowItemsFromOtherCharacters;
						addon:UpdateFrame();
					end,
		},
		ValueToShow = {
			type = "select",
			name = L["Value to show"],
			order = 12,
			values = function() return SHOWN_VALUE end,
			get = function() return addon.db.profile.ShownValue; end,
			set = function(info, name) 
						addon.db.profile.ShownValue = name;
						addon:UpdateFrame();
				end,
		},
		header2 = {
			type = "header",
			name = L["Frame Options"],
			order = 13,
		},
		UISize = {
			type = "range",
			name = L["UI Scale"],
			width = "double",
			order = 14,
			min	= .5,
			max	= 1.5,
			step	= .05,
			bigStep = .05,
			get = function() return addon.db.profile.UIScale end,
			set = function(info, v)
						addon.db.profile.UIScale = v;
						addon:UpdateFrame();
					end,
		},
		numberOfColumns = {
			type = "range",
			name = L["Number Of Columns"],
			width = "double",
			order = 15,
			min = 1,
			max = 20,
			step = 1,
			bigStep = 1,
			get = function() return addon.db.profile.numberOfColumns end,
			set = function(info, v)
						addon.db.profile.numberOfColumns = v;
						addon:UpdateFrame();
				end,
		},
		ButtonPosition = {
			type = "range",
			name = L["Button Position"],
			width = "double",
			order = 16,
			min = 1,
			max = 360,
			step = 1,
			bigStep = 1,
			get = function() return addon.db.profile.MinimapButtonPosition end,
			set = function(info, v)
						addon.db.profile.MinimapButtonPosition = v;
						addon:UpdateButtonPosition();
				end,
		},
	}
}

